module VueCompiler
  module Token
    class EndOfSource end

    class CommentStart end

    class Comment
      attr_reader :value

      def initialize(value)
        @value = value
      end
    end

    class CommentEnd end

    class OpenTagStart end

    class ClosingTagStart end

    class TagEnd end

    class SelfClosingTag end

    class TagName
      attr_reader :name

      def initialize(name)
        @name = name
      end
    end

    class OpenTagName < TagName
    end

    class ClosingTagName < TagName
    end

    class AttributeName
      attr_reader :name

      def initialize(name)
        @name = name
      end
    end

    class AttributeValue
      attr_reader :value

      def initialize(value)
        @value = value
      end
    end

    class Text
      attr_reader :content

      def initialize(content)
        @content = content
      end
    end

    class InterpolationStart
    end

    class Interpolation
      attr_reader :expression

      def initialize(expression)
        @expression = expression
      end
    end

    class InterpolationEnd
    end

    class ScriptBlock
      attr_reader :content, :lang

      def initialize(content, lang = 'js')
        @content = content
        @lang = lang
      end
    end

    class StyleBlock
      attr_reader :content, :lang, :scoped

      def initialize(content, lang = 'css', scoped = false)
        @content = content
        @lang = lang
        @scoped = scoped
      end
    end

    class CustomBlock
      attr_reader :type, :attributes, :content

      def initialize(type, content, attributes = {})
        @type = type
        @content = content
      end
    end
  end
end
